==> dpws-model-1.1.0-sources.jar: org/somda/sdc/dpws/soap/wsaddressing/model/ProblemActionType.java <==

package org.somda.sdc.dpws.soap.wsaddressing.model;

import java.util.HashMap;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * <p>Java class for ProblemActionType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ProblemActionType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2005/08/addressing}Action" minOccurs="0"/&gt;
 *         &lt;element name="SoapAction" type="{http://www.w3.org/2001/XMLSchema}anyURI" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ProblemActionType", namespace = "http://www.w3.org/2005/08/addressing", propOrder = {
    "action",
    "soapAction"
})
public class ProblemActionType implements ToString2
{

    @XmlElement(name = "Action", namespace = "http://www.w3.org/2005/08/addressing")
    protected AttributedURIType action;
    @XmlElement(name = "SoapAction", namespace = "http://www.w3.org/2005/08/addressing")
    @XmlSchemaType(name = "anyURI")
    protected String soapAction;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Ruft den Wert der action-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link AttributedURIType }
     *     
     */
    public AttributedURIType getAction() {
        return action;
    }

    /**
     * Legt den Wert der action-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link AttributedURIType }
     *     
     */
    public void setAction(AttributedURIType value) {
        this.action = value;
    }

    /**
     * Ruft den Wert der soapAction-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSoapAction() {
        return soapAction;
    }

    /**
     * Legt den Wert der soapAction-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSoapAction(String value) {
        this.soapAction = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final ProblemActionType that = ((ProblemActionType) object);
        {
            AttributedURIType leftAction;
            leftAction = this.getAction();
            AttributedURIType rightAction;
            rightAction = that.getAction();
            if (this.action!= null) {
                if (that.action!= null) {
                    if (!leftAction.equals(rightAction)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.action!= null) {
                    return false;
                }
            }
        }
        {
            String leftSoapAction;
            leftSoapAction = this.getSoapAction();
            String rightSoapAction;
            rightSoapAction = that.getSoapAction();
            if (this.soapAction!= null) {
                if (that.soapAction!= null) {
                    if (!leftSoapAction.equals(rightSoapAction)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.soapAction!= null) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            AttributedURIType theAction;
            theAction = this.getAction();
            if (this.action!= null) {
                currentHashCode += theAction.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theSoapAction;
            theSoapAction = this.getSoapAction();
            if (this.soapAction!= null) {
                currentHashCode += theSoapAction.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            AttributedURIType theAction;
            theAction = this.getAction();
            strategy.appendField(locator, this, "action", buffer, theAction, (this.action!= null));
        }
        {
            String theSoapAction;
            theSoapAction = this.getSoapAction();
            strategy.appendField(locator, this, "soapAction", buffer, theSoapAction, (this.soapAction!= null));
        }
        return buffer;
    }

}

==> dpws-model-2.0.0-sources.jar: org/somda/sdc/dpws/soap/wsaddressing/model/ProblemActionType.java <==

package org.somda.sdc.dpws.soap.wsaddressing.model;

import java.util.HashMap;
import java.util.Map;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAnyAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.namespace.QName;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * <p>Java class for ProblemActionType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ProblemActionType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.w3.org/2005/08/addressing}Action" minOccurs="0"/&gt;
 *         &lt;element name="SoapAction" type="{http://www.w3.org/2001/XMLSchema}anyURI" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;anyAttribute processContents='lax' namespace='##other'/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ProblemActionType", namespace = "http://www.w3.org/2005/08/addressing", propOrder = {
    "action",
    "soapAction"
})
public class ProblemActionType implements ToString2
{

    @XmlElement(name = "Action", namespace = "http://www.w3.org/2005/08/addressing")
    protected AttributedURIType action;
    @XmlElement(name = "SoapAction", namespace = "http://www.w3.org/2005/08/addressing")
    @XmlSchemaType(name = "anyURI")
    protected String soapAction;
    @XmlAnyAttribute
    private Map<QName, String> otherAttributes = new HashMap<QName, String>();

    /**
     * Gets the value of the action property.
     * 
     * @return
     *     possible object is
     *     {@link AttributedURIType }
     *     
     */
    public AttributedURIType getAction() {
        return action;
    }

    /**
     * Sets the value of the action property.
     * 
     * @param value
     *     allowed object is
     *     {@link AttributedURIType }
     *     
     */
    public void setAction(AttributedURIType value) {
        this.action = value;
    }

    /**
     * Gets the value of the soapAction property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSoapAction() {
        return soapAction;
    }

    /**
     * Sets the value of the soapAction property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSoapAction(String value) {
        this.soapAction = value;
    }

    /**
     * Gets a map that contains attributes that aren't bound to any typed property on this class.
     * 
     * <p>
     * the map is keyed by the name of the attribute and 
     * the value is the string value of the attribute.
     * 
     * the map returned by this method is live, and you can add new attribute
     * by updating the map directly. Because of this design, there's no setter.
     * 
     * 
     * @return
     *     always non-null
     */
    public Map<QName, String> getOtherAttributes() {
        return otherAttributes;
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final ProblemActionType that = ((ProblemActionType) object);
        {
            AttributedURIType leftAction;
            leftAction = this.getAction();
            AttributedURIType rightAction;
            rightAction = that.getAction();
            if (this.action!= null) {
                if (that.action!= null) {
                    if (!leftAction.equals(rightAction)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.action!= null) {
                    return false;
                }
            }
        }
        {
            String leftSoapAction;
            leftSoapAction = this.getSoapAction();
            String rightSoapAction;
            rightSoapAction = that.getSoapAction();
            if (this.soapAction!= null) {
                if (that.soapAction!= null) {
                    if (!leftSoapAction.equals(rightSoapAction)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.soapAction!= null) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            AttributedURIType theAction;
            theAction = this.getAction();
            if (this.action!= null) {
                currentHashCode += theAction.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theSoapAction;
            theSoapAction = this.getSoapAction();
            if (this.soapAction!= null) {
                currentHashCode += theSoapAction.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            AttributedURIType theAction;
            theAction = this.getAction();
            strategy.appendField(locator, this, "action", buffer, theAction, (this.action!= null));
        }
        {
            String theSoapAction;
            theSoapAction = this.getSoapAction();
            strategy.appendField(locator, this, "soapAction", buffer, theSoapAction, (this.soapAction!= null));
        }
        return buffer;
    }

}
